@@ -1,5 +1,5 @@
 /**
- * jQuery Messages UI 0.1.3
+ * jQuery Messages UI 0.1.4
  *
  * Copyright (c) 2011, Jonny Gerig Meyer
  * All rights reserved.
@@ -7,49 +7,57 @@
  * Licensed under the New BSD License
  * See: http://www.opensource.org/licenses/bsd-license.php
  */
-(function($) {
-    $.fn.messages = function(opts) {
+
+/*jslint    browser:    true,
+            indent:     4,
+            confusion:  true */
+/*global    jQuery, ich */
+
+(function ($) {
+
+    'use strict';
+
+    $.fn.messages = function (opts) {
         var messageList = $(this),
-        options = $.extend({}, $.fn.messages.defaults, messageList.data('messages-ui-opts'), opts),
-        messages = messageList.find(options.message),
-        transientMessages = messages.filter(options.transientMessage);
+            options = $.extend({}, $.fn.messages.defaults, messageList.data('messages-ui-opts'), opts),
+            messages = messageList.find(options.message),
+            transientMessages = messages.filter(options.transientMessage);
         messageList.data('messages-ui-opts', options);
         if (options.closeLink) {
-            messageList.find(options.closeLink).click(function() {
+            messageList.find(options.closeLink).click(function () {
                 var thisMessage = $(this).closest(options.message);
-                thisMessage.fadeOut('fast', function() {
+                thisMessage.fadeOut('fast', function () {
                     thisMessage.detach();
                 });
                 return false;
             });
         }
         if (transientMessages.length) {
-            $(document).bind('mousedown keydown', function(event) {
-                $.doTimeout(options.transientDelay, function() {
-                    transientMessages.fadeOut(options.transientFadeSpeed, function() {
+            $(document).bind('mousedown keydown', function (event) {
+                $.doTimeout(options.transientDelay, function () {
+                    transientMessages.fadeOut(options.transientFadeSpeed, function () {
                         transientMessages.detach();
                     });
                     $(this).unbind(event);
                 });
             });
         }
-        if (options.handleAjax)
-            $.ajaxSetup(
-                {
-                    dataType: "json",
-                    dataFilter: function(data, type) {
-                        if (type == "json") {
-                            var parsed = $.parseJSON(data),
+        if (options.handleAjax) {
+            $.ajaxSetup({
+                dataType: "json",
+                dataFilter: function (data, type) {
+                    if (type === "json") {
+                        var parsed = $.parseJSON(data),
                             messages = $(parsed.messages);
-                            messages.each(function() {
-                                $(ich.message(this)).appendTo(messageList);
-                            });
-                            messageList.messages();
-                        }
-                        return data;
+                        messages.each(function () {
+                            $(ich.message(this)).appendTo(messageList);
+                        });
+                        messageList.messages();
                     }
+                    return data;
                 }
-            );
+            });
+        }
     };
 
     /* Setup plugin defaults */
@@ -61,4 +69,4 @@
         transientFadeSpeed: 3000,       // Fade speed for transient messages (ms)
         handleAjax: false               // Enable automatic handling of messages in "messages" key of JSON AJAX response
     };
-})(jQuery);
+}(jQuery));
